import QtQuick 2.0
import Ubuntu.Components 1.1
import "TelegramColors.js" as TelegramColors

MouseArea {
    property alias image: image.source
    property alias title: title.text
    property string lastSeen
    property bool isOnline: false

    id: listitem
    width: parent.width
    height: units.gu(7)

    Rectangle {
        id: background
        anchors.fill: parent
        color: listitem.pressed ? TelegramColors.list_pressed : TelegramColors.white
    }

    UbuntuShape {
        id: imageShape
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom

            topMargin: units.dp(4)
            bottomMargin: units.dp(4)
            leftMargin: units.gu(1)
            rightMargin: units.gu(1)
        }
        width: height

        image: Image {
            id: image
            anchors.fill: parent
            antialiasing: true
            asynchronous: true
            fillMode: Image.PreserveAspectFit
        }
    }

    Text {
        id: title
        anchors {
            top: parent.top
            left: imageShape.right
            right: parent.right

            topMargin: units.gu(1)
            leftMargin: units.gu(1)
        }
        verticalAlignment: TextInput.AlignVCenter

        font.weight: Font.DemiBold
        font.pointSize: 12
        color: TelegramColors.black
        text: "Contact"
    }

    Text {
        id: subtitle
        anchors {
            top: title.bottom
            left: imageShape.right
            bottom: parent.bottom
            right: parent.left

            leftMargin: units.gu(1)
            bottomMargin: units.gu(1)
        }
        verticalAlignment: TextInput.AlignVCenter

        font.pointSize: 10
        color: isOnline ? TelegramColors.dark_blue : TelegramColors.grey
        text: "Last seen"
    }

    onLastSeenChanged: updateLastSeen(lastSeen)

    onIsOnlineChanged: updateLastSeen(lastSeen)

    function updateLastSeen(lastSeen) {
       if (isOnline) {
            subtitle.text = i18n.tr("online");
        } else {
            subtitle.text = "last seen " + lastSeen;
        }
    }
}
