import QtQuick 2.0
import Ubuntu.Components 1.1
import "TelegramColors.js" as TelegramColors

MouseArea {
    property alias image: image.source
    property alias title: title.text
    property alias subtitle: subtitle.text
    property alias unread: unread.text
    property alias time: time.text
    property bool isGroup: false
    property bool isNewGroup: false
    property bool isMedia: false
    property int delivery: 0

    readonly property int delivery_none: 0
    readonly property int delivery_sent: 1
    readonly property int delivery_read: 2

    id: listitem
    width: parent.width
    height: units.gu(7)

    Rectangle {
        id: background
        anchors.fill: parent
        color: listitem.pressed ? TelegramColors.list_pressed : TelegramColors.white
    }

    UbuntuShape {
        id: imageShape
        anchors {
            top: parent.top
            left: parent.left
            bottom: parent.bottom

            topMargin: units.dp(4)
            bottomMargin: units.dp(4)
            leftMargin: units.gu(1)
            rightMargin: units.gu(1)
        }
        width: height

        image: Image {
            id: image
            anchors.fill: parent
            antialiasing: true
            asynchronous: true
            fillMode: Image.PreserveAspectFit
        }
    }

    Image {
        id: grouplistIndicator
        anchors {
            top: parent.top
            left: imageShape.right

            topMargin: units.gu(1.5)
            leftMargin: units.gu(1)
            rightMargin: units.gu(1)
        }
        width: visible ? units.gu(3) : 0
        fillMode: Image.PreserveAspectFit

        source: Qt.resolvedUrl("../images/grouplist.png")
        visible: isGroup
    }

    Text {
        id: time
        anchors {
            top: parent.top
            right: parent.right

            margins: units.dp(4)
            rightMargin: units.gu(1)
        }
        height: parent.height/2
        horizontalAlignment: Text.AlignRight
        verticalAlignment: Text.AlignVCenter

        color: TelegramColors.grey
        text: "Wed"
    }

    Rectangle {
        id: unreadBoundingBox
        anchors {
            right: parent.right
            bottom: parent.bottom

            margins: units.dp(4)
            rightMargin: units.gu(1)
        }
        width: time.width
        height: time.height

        visible: unread.text != "" && unread.text != "0"

        Rectangle {
            id: unreadBox
            anchors {
                right: parent.right
                verticalCenter: parent.verticalCenter
            }
            width: Math.max(units.gu(2.8), unread.width + units.gu(1))
            height: units.gu(2.5)
            radius: 2

            color: TelegramColors.unread_green

            Text {
                id: unread
                anchors {
                    centerIn: parent
                    topMargin: units.dp(4)
                    rightMargin: time.anchors.rightMargin
                    leftMargin: time.anchors.leftMargin
                }
                horizontalAlignment: TextInput.AlignHCenter
                verticalAlignment: TextInput.AlignVCenter

                font.weight: Font.DemiBold
                font.pointSize: 10
                color: TelegramColors.white
                text: "6"
            }
        }
    }

    Image {
        id: sentIndicator
        anchors {
            verticalCenter: time.verticalCenter
            right: time.left
            topMargin: time.anchors.topMargin
            rightMargin: units.dp(8)
        }
        width: units.gu(2)
        z: 1
        fillMode: Image.PreserveAspectFit

        source: (delivery >= delivery_sent) ? Qt.resolvedUrl("../images/dialogs_check.png") : ""
    }

    Image {
        id: deliveredIndicator
        anchors {
            verticalCenter: time.verticalCenter
            right: time.left
            topMargin: time.anchors.topMargin
            rightMargin: sentIndicator.anchors.rightMargin - units.dp(5)
        }
        width: units.gu(2)
        z: 2
        fillMode: Image.PreserveAspectFit

        source: (delivery == delivery_read) ? Qt.resolvedUrl("../images/dialogs_halfcheck.png") : ""
    }

    Text {
        id: title
        anchors {
            top: parent.top
            left: grouplistIndicator.right
            bottom: time.bottom
            right: sentIndicator.left

            leftMargin: units.dp(4)
        }
        verticalAlignment: TextInput.AlignVCenter

        font.weight: Font.DemiBold
        font.pointSize: 12
        color: TelegramColors.black
        text: "Telegram"
    }

    Text {
        id: subtitle
        anchors {
            top: title.bottom
            left: isGroup ? imageShape.right : title.left
            bottom: parent.bottom
            right: unreadBoundingBox.left

            leftMargin: isGroup ? units.gu(1) : 0
        }
        verticalAlignment: TextInput.AlignVCenter

        font.pointSize: 11
        color: isMedia || isNewGroup ? TelegramColors.dark_blue : TelegramColors.grey
        text: "This is a test message."
    }
}
