import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Plugins.Telegram 0.1
import "ui"

MainView {
    id: root
    // For autopilot-qt4 functional testing.
    objectName: "mainView"

    // Must match "name" in click manifest.
    applicationName: "com.ubuntu.telegram"

    automaticOrientation: false

    useDeprecatedToolbar: false

    width: units.gu(45)
    height: units.gu(80)

    PageStack {
        id: pageStack

        SplashPage {
            id: splashPage
            visible: false
        }

        IntroPage {
            id: introPage
            visible: false
        }

        SignInPage {
            id: signInPage
            visible: false
        }

        SignUpPage {
            id: signUpPage
            visible: false
        }

        VerificationCodePage {
            id: verificationCodePage
            visible: false
        }

        DialogsPage {
            id: dialogsPage
            visible: false
        }

        DialogPage {
            id: dialogPage
            visible: false
        }

        ContactsPage {
            id: contactsPage
            visible: false
        }

        Component.onCompleted: showPage(introPage)

        function showPage(page) {
            if (pageStack.depth > 0)
                pageStack.pop();
            pageStack.push(page);
        }
    }

    TelegramClient {
        id: telegramClient
        configPath: "~/.libqtelegram"
        publicKeyFile: "telegram.pub"

        onError: {
            // TODO Replace these with constants.
            if (errorCode == 420) {
                console.log("[Error] " + errorText);
                var text = i18n.tr("Please wait a moment and try again");
                signInPage.onError(text);
                verificationCodePage.onError(text);
            } else if (errorText == "PHONE_NUMBER_INVALID") {
                console.log("[Error] " + errorText);
                signInPage.onError(
                        i18n.tr("Incorrect phone number"));
            } else if (errorText == "PHONE_CODE_INVALID") {
                console.log("[Error] " + errorText);
                verificationCodePage.onError(
                        i18n.tr("Incorrect code"));
            } else {
                var msg = errorCode + " " + errorText;
                console.log("Unhandled error: " + msg)
            }
        }

        onAuthNeeded: authCheckPhone();

        onAuthSignInError: {
            verificationCodePage.onError(i18n.tr(
                    "The code you have entered is not valid. Try again"));
        }

        onAuthSignUpError: {
            verificationCodePage.onError(i18n.tr(
                    "The code you have entered is not valid. Try again"));
        }

        onAuthCheckPhoneAnswer: {
            if (phoneRegistered) {
                authSendCode();
            } else {
                pageStack.showPage(signUpPage);
            }
        }

        onAuthSendCodeAnswer: {
            pageStack.showPage(verificationCodePage);
            verificationCodePage.startTimer();
        }

        onAuthSendCallAnswer: {
            verificationCodePage.calling();
        }

        onMessagesGetDialogsAnswer: {
            pageStack.showPage(dialogsPage);
        }
    }
}
