import QtQuick 2.0
import Ubuntu.Components 0.1
import "../components"
import Ubuntu.Plugins.Telegram 0.1

TelegramPage {
    id: page

    head.actions: [
            Action {
                iconName: "insert-image"
                text: i18n.tr("Attach")
            },
            Action {
                iconName: "contact"
                text: i18n.tr("Profile")
            }
        ]

    body: Rectangle {
        anchors {
            fill: parent
        }

        Image {
            anchors.fill: parent
            source: Qt.resolvedUrl("../images/background_hd.jpg");
        }

        // TODO Figure out what is wrong with header backAction.
        TelegramButton {
            id: back
            anchors {
                bottom: parent.bottom
                left: parent.left
                right: parent.right

                margins: units.gu(1)
            }

            text: "Back"
            onClicked: pageStack.showPage(dialogsPage)
        }

        TextField {
            id: message
            anchors {
                left: parent.left
                bottom: back.top
                right: parent.right

                margins: units.gu(1)
            }

            placeholderText: i18n.tr("Type message")
            inputMethodHints: Qt.ImhNone

            onAccepted: sendMessage(message.text)
        }

        ListView {
            id: list
            anchors {
                left: parent.left
                bottom: message.top
                right: parent.right
                top: parent.top

                margins: units.gu(1)
            }
            clip: true

            delegate: TelegramBubble {
                isOutgoing: model.out
                text: model.text
            }

            // FIXME This is a terrible hack. onCountChange has super weird behavior.
            // Let's use this for now, iterate on it and find a real solution.
            onCountChanged: timer.start()

            Timer {
                id: timer

                interval: 200
                repeat: false
                onTriggered: list.positionViewAtEnd()
            }
        }
    }

    function updateChat(title, peerId, peerIsChat) {
        page.title = title;
        if (peerIsChat) {
            inputPeer.classType = TLInputPeer.TypeInputPeerChat;
            inputPeer.chatId = peerId;
        } else {
            inputPeer.classType = TLInputPeer.TypeInputPeerContact;
            inputPeer.userId = peerId;
        }
        list.model = telegramClient.getMessagesModelOfDialog(peerId);
    }

    function sendMessage(text) {
        if (text.length === 0) return;
        telegramClient.messagesSendMessage(inputPeer, text);
        message.text = "";
    }

    TLInputPeer {
        id: inputPeer
    }
}
