import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0
import "../components"
import "../components/listitems"
import "../js/time.js" as Time
import Ubuntu.Plugins.Telegram 0.1

TelegramPage {
    title: i18n.tr('Telegram');

    head.actions: [
            Action {
                iconName: "search"
                text: i18n.tr("Search")
            },
            Action {
                iconName: "compose"
                text: i18n.tr("Compose")
            },
            Action {
                text: i18n.tr("TBD New Group")
            },
            Action {
                text: i18n.tr("TBD Contacts")
                onTriggered: pageStack.showPage(contactsPage)
            },
            Action {
                text: i18n.tr("TBD Settings")
            }
        ]

    body: Rectangle {
        anchors {
            fill: parent
        }

        ListView {
            id: dialogsListView
            anchors.fill: parent
            clip: true

            model: telegramClient.dialogsModel
            delegate: TelegramDialogsListItem {
                image: model.thumbnail !== "" ?
                           model.thumbnail : Qt.resolvedUrl("../images/user_blue.png")
                isGroup: model.isChat
                title: model.name
                subtitle: {
                    if (model.typing) {
                        return i18n.tr("typing...");
                    } else {
                        if (model.topMessageText === "" && isGroup) {
                            isNewGroup = true;
                            return model.topMessageFromFirstName + " " + i18n.tr("added you");
                        }

                        var type = dialogsListView.getType(model);
                        if (type === "Text") {
                            isMedia = false;
                            return model.topMessageText
                        } else {
                            isMedia = true;
                            return type;
                        }
                    }
                }
                time: Time.format(model.topMessageDate * 1000)
                unread: model.unreadCount
                delivery: dialogsListView.getDeliveryState(model)

                onClicked: {
                    dialogPage.updateChat(model.name, model.id, model.isChat);
                    pageStack.showPage(dialogPage);
                }
            }

            function getType(message) {
                var mediaType = message.topMessageMediaType;
                // Switch has cleaner syntax than multiple if-else-if
                switch (true) {
                case mediaType === TLMessageMedia.TypeMessageMediaEmpty:
                    return "Text";
                case mediaType === TLMessageMedia.TypeMessageMediaPhoto:
                    return "Photo";
                default:
                    // TODO add more media types
                    return "Other";
                }
            }

            function getDeliveryState(message) {
                if (message.topMessageFromId === telegramClient.ourId) {
                    return message.topMessageUnread ? 1 : 2;
                        // TODO Figure out why this doesn't work.
                        // TelegramDialogsListItem.delivery_sent : TelegramDialogsListItem.delivery_read;
                }
                return 0;
            }
        } // ListView
    } // body
}
