import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Telephony.PhoneNumber 0.1
import "../components/country_data.js" as CountryData
import "../components"

TelegramPage {
    property alias errorLabel: errorLabel

    title: i18n.tr('Your phone')

    head.actions: [
        Action {
            iconName: "ok"
            text: i18n.tr("Done")
            onTriggered: done()
        }
    ]

    body: Rectangle {
        anchors {
            fill: parent
            margins: units.gu(2)
        }

        OptionSelector {
            id: countrySelector
            anchors {
                top: parent.top
                topMargin: units.gu(1)
            }
            containerHeight: itemHeight * 6

            onDelegateClicked: {
                var country = model[index]
                var tel = CountryData.name_to_tel[country]
                countryTextField.text = tel
                userTextField.defaultRegion = CountryData.tel_to_iso[tel]
                userTextField.focus = true
            }

            Component.onCompleted: {
                var countries = []
                for (var c in CountryData.name_to_tel) {
                    countries.push(c)
                }
                countrySelector.model = countries
                // lolz
                //countrySelector.selectedIndex = countries.indexOf('United States')

            }
        }

        Row {
            id: userEntryRow
            anchors {
                top: countrySelector.bottom
                topMargin: units.gu(1)
            }
            height: signInButton.height
            width: parent.width

            Label {
                id: label
                text: "+"
                width: units.gu(2)
                height: parent.height
                verticalAlignment: TextInput.AlignVCenter
            }
            TextField {
                id: countryTextField
                horizontalAlignment: TextInput.AlignHCenter
                width: units.gu(8)

                validator: RegExpValidator {
                    regExp: /[0-9]*/
                }
                placeholderText: {
                    CountryData.iso_to_tel[userTextField.defaultRegion]
                }

                KeyNavigation.tab: userTextField
                onDisplayTextChanged: {
                    var tel = countryTextField.text
                    var country = CountryData.tel_to_name[tel]
                    countrySelector.selectedIndex = countrySelector.model.indexOf(country)
                    userTextField.defaultRegion = CountryData.tel_to_iso[tel]
                }
            }
            // XXX: Requires private API - http://pad.lv/1346450
            PhoneNumberField {
                id: userTextField
                horizontalAlignment: TextInput.AlignHCenter

                width: countrySelector.width - countryTextField.width - label.width

                focus: true
                cursorVisible: true
                updateOnlyWhenFocused: false
                defaultRegion: "US"
                autoFormat: userTextField.text.length > 0 && userTextField.text.charAt(0) !== "*" && userTextField.text.charAt(0) !== "#"

                // force cursor to be always visible
                onCursorVisibleChanged: {
                    if (!cursorVisible)
                        cursorVisible = true
                }

                onDisplayTextChanged: clearError()
                Keys.onEnterPressed: done()
                Keys.onReturnPressed: done()
            }
        }

        TelegramLabel {
            id: infoLabel
            anchors {
                top: userEntryRow.bottom
                margins: units.gu(1)
                topMargin: units.gu(4)
            }
            width: parent.width
            text: i18n.tr("Please confirm your country code\nand enter your phone number.")
        }

        TelegramLabel {
            id: errorLabel
            anchors {
                top: infoLabel.bottom
                margins: units.gu(1)
            }
            width: parent.width
            visible: false
            color: "red"
        }

        TelegramButton {
            // TODO: Do we want this as well, or Header action only?
            id: signInButton
            anchors {
                top: errorLabel.bottom
                topMargin: units.gu(1)
            }
            width: parent.width
            text: i18n.tr("Next")
            visible: false

            onClicked: done();
        }
    }

    function done() {
        if (userTextField.text.length > 0) {
            userTextField.enabled = false;
            signInButton.enabled = false;
            telegramClient.phoneNumber = "+" + countryTextField.text + userTextField.text;
            telegramClient.initTelegramLibrary();
        }
    }

    function onError(errorMessage) {
        setError(errorMessage);
        userTextField.enabled = true;
        signInButton.enabled = true;
    }

    function setError(message) {
        errorLabel.text = message;
        errorLabel.visible = true;
    }

    function clearError() {
        if (errorLabel.visible) {
            errorLabel.visible = false;
            errorLabel.text = "";
        }
    }
}
