import QtQuick 2.0
import Ubuntu.Components 0.1
import "../components"

TelegramPage {
    property alias errorlabel: errorLabel
    property alias firstNameTextField: firstName
    property alias lastNameTextField: lastName
    property alias signUpButton: signUpButton

    title: i18n.tr('Sign up')

    head.actions: [
        Action {
            iconName: "ok"
            text: i18n.tr("Done")
            onTriggered: done()
        }
    ]

    body: Rectangle {
        anchors {
            fill: parent
            margins: units.gu(2)
        }

        TelegramLabel {
            id: infoLabel
            anchors {
                top: parent.top
                margins: units.gu(1)
            }
            width: parent.width
            text: i18n.tr("Your first and last name:")
        }

        TelegramLabel {
            id: errorLabel
            anchors {
                top: infoLabel.bottom
                margins: units.gu(1)
            }
            width: parent.width
            visible: false
            color: "red"
        }

        TgTextField {
            id: firstName
            anchors {
                top: errorLabel.bottom
                topMargin: units.gu(1)
            }
            height: signUpButton.height

            validator: RegExpValidator {
                regExp: /[\w\s]+/
            }
            placeholderText: i18n.tr("First name (required)")

            onDisplayTextChanged: clearError()
            Keys.onReturnPressed: lastName.forceActiveFocus()
        }

        TgTextField {
            id: lastName
            anchors {
                top: firstName.bottom
                topMargin: units.gu(1)
            }
            height: signUpButton.height
            placeholderText: i18n.tr("Last name (optional)")
            validator: RegExpValidator{ regExp: /[\w\s]+/ }

            Keys.onReturnPressed: done()
        }

        TelegramButton {
            // TODO: Do we want this as well, or Header action only?
            id: signUpButton
            anchors {
                top: lastName.bottom
                topMargin: units.gu(1)
            }
            width: parent.width
            text: i18n.tr("Next")
            visible: false

            onClicked: done();
        }
    }

    function done() {
        if (firstName.text.length > 0){
            firstName.enabled = false;
            lastName.enabled = false;
            signUpButton.enabled = false;
            telegramClient.authSendCode();
        } else {
            onError(i18n.tr("First name is required"))
        }
    }

    // TODO Possibly refactor these out from Sign*Page(s).qml

    function onError(errorMessage) {
        setError(errorMessage);
        userTextField.enabled = true;
        signInButton.enabled = true;
    }

    function setError(errorMessage) {
        errorLabel.text = errorMessage;
        errorLabel.visible = true;
    }

    function clearError() {
        if (errorLabel.visible) {
            errorLabel.visible = false;
            errorLabel.text = "";
        }
    }
}
