import QtQuick 2.0
import Ubuntu.Components 0.1
import "../components"

TelegramPage {
    property alias codeTextField: codeTextField
    property alias verifyButton: verifyButton
    property alias errorLabel: errorLabel
    property alias countdownText: countdownLabel.text
    property alias countdownTimer: countdownTimer

    title: i18n.tr('Your code')

    head.actions: [
        Action {
            iconName: "ok"
            text: i18n.tr("Done")
            onTriggered: done()
        }
    ]

    body: Rectangle {
        anchors {
            fill: parent
            margins: units.gu(2)
        }

        TelegramLabel {
            id: infoLabel
            anchors {
                top: parent.top
                margins: units.gu(1)
            }
            width: parent.width
            text: i18n.tr("We've sent an SMS with an activation code.\nPlease enter it below.\n")
        }

        TelegramLabel {
            id: countdownLabel
            anchors {
                top: infoLabel.bottom
                topMargin: units.gu(1)
            }
            width: parent.width
            text: i18n.tr("We will call you in ") + countdownTimer.getTimeAsText()
        }

        TelegramLabel {
            id: errorLabel
            anchors {
                top: countdownLabel.bottom
                topMargin: units.gu(1)
            }
            width: parent.width
            visible: false
            color: "red"
        }

        TgTextField {
            id: codeTextField
            anchors {
                top: errorLabel.bottom
                topMargin: units.gu(1)
            }
            height: verifyButton.height

            validator: RegExpValidator {
                regExp: /[\w]+/
            }
            placeholderText: i18n.tr("Code")

            Keys.onEnterPressed: done()
            Keys.onReturnPressed: done()
        }

        TelegramButton {
            // TODO: Do we want this as well, or Header action only?
            id: verifyButton
            anchors {
                top: codeTextField.bottom
                topMargin: units.gu(1)
            }
            width: parent.width
            text: i18n.tr('Done');
            visible: false

            onClicked: done()
        }
    }

    Timer {
        id: countdownTimer
        property int seconds: 120
        interval: 1000
        repeat: true
        running: false

        onTriggered: {
            countdownLabel.text = i18n.tr("We will call you in ") + getTimeAsText();
            seconds--;
            if (seconds < 0) {
                stop();
                telegramClient.authSendCall();
            }
        }

        function getTimeAsText() {
            var min = Math.floor(seconds / 60);
            var sec = (seconds % 60).toString()

            var pad = "00";
            sec = pad.substring(0, pad.length - sec.length) + sec;
            return min + ':' + sec;
        }
    }

    function startTimer() {
        countdownTimer.start();
    }

    function calling() {
        countdownLabel.text = i18n.tr("Calling you...");
    }

    function done() {
        if (codeTextField.text.length > 0) {
            codeTextField.enabled = false;
            verifyButton.enabled = false;
            if (signUpPage.firstNameTextField.text.length > 0) {
                telegramClient.authSignUp(codeTextField.text,
                        signUpPage.firstNameTextField.text,
                        signUpPage.lastNameTextField.text);
            } else {
                telegramClient.authSignIn(codeTextField.text);
            }
        }
    }

    function onError(errorMessage) {
        codeTextField.text = "";
        codeTextField.enabled = true;
        verifyButton.enabled = true;
        setError(errorMessage);
    }

    function setError(message) {
        errorLabel.text = message;
        errorLabel.visible = true;
    }

    function clearError() {
        if (errorLabel.visible) {
            errorLabel.visible = false;
            errorLabel.text = "";
        }
    }
}
